#!/bin/bash

# Exit immediately if a command exits with a non-zero status.
set -e

# This script assumes you have already configured the .env.local file in the photos app directory

# set the local repo location
LOCAL_REPO="~/src/ente"

cd $LOCAL_REPO/web

yarn install
yarn build:photos # puts the built files in the web/apps/photos/out directory

sudo cp -r apps/photos/out /var/www/ente/photos

# configure nginx to serve the photos app on ente.sa.vin
sudo tee /etc/nginx/sites-available/ente.sa.vin.conf > /dev/null <<EOL
server {
    listen 80;
    server_name ente.sa.vin;

    location / {
        root /var/www/ente/photos;
        index index.html;
        try_files \$uri /index.html;
    }
}
EOL

# create a symbolic link to enable the site
sudo ln -s /etc/nginx/sites-available/ente.sa.vin.conf /etc/nginx/sites-enabled/

# Also configure nginx to serve the same photos app on entep.sa.vin
sudo tee /etc/nginx/sites-available/entep.sa.vin.conf > /dev/null <<EOL
server {
    listen 80;
    server_name entep.sa.vin;

    location / {
        root /var/www/ente/photos;
        index index.html;
        try_files \$uri /index.html;
    }
}
EOL

# reload nginx to apply changes
sudo systemctl reload nginx

# use certbot to add SSL certificate for the photos app
sudo certbot --nginx -d ente.sa.vin -d entep.sa.vin

echo "Ente web app has been set up successfully. Access the app at https://ente.sa.vin or https://entep.sa.vin"